# SGNL (SGN inspiraL)

SGNL is a CBC search pipeline implemented using SGN. This page is for the application-specific
library `sgnl`, but there is a family of libraries that extend the functionality of SGN,
including:

- [`sgn`](https://docs.ligo.org/greg/sgn/): Base library for SGN
- [`sgn-ts`](https://docs.ligo.org/greg/sgn-ts/): TimeSeries utilities for SGN
- [`sgn-ligo`](https://docs.ligo.org/greg/sgn-ligo/): LSC specific utilities for SGN

## Installation

To install SGNL, simply run:

```bash
pip install sgnl
```

More SGNL-specific documentation coming soon.
